@@ -6,28 +6,39 @@ package DBIx::DataModel;
 use 5.008;
 use warnings;
 use strict;
-use version;
-use MRO::Compat;
-use DBIx::DataModel::Meta::Utils qw/does/;
-use Carp::Clan qw[^(DBIx::DataModel::|SQL::Abstract)];
+use MRO::Compat  (); # don't want to call MRO::Compat::import()
 
-our $VERSION = '2.47_08';
+our $VERSION = '2.01';
+$VERSION = eval $VERSION if $VERSION =~ /_/; # numify
 
-# compatibility setting : see import()
-our $COMPATIBILITY = $VERSION; # from 2.20, no longer automatic compatibility
+# compatibility setting : see import(); for the moment, automatic compat 1.0
+our $COMPATIBILITY = 1.0;
+# future : our $COMPATIBILITY = $VERSION;
 
-sub import {
-  my ($class, %args) = @_;
-  if (exists $args{-compatibility}) {
-    $COMPATIBILITY = $args{-compatibility} # explicit number
-                  || $VERSION;             # undef : means no compatibility
-  }
-
-  require DBIx::DataModel::Compatibility::V1
-    if version->parse($COMPATIBILITY) < version->parse("1.99");
-  require DBIx::DataModel::Compatibility::V0
-    if version->parse($COMPATIBILITY) < version->parse("1.00");
-}
+# Modules considered to belong to the same family for carp/croak (see L<Carp>).
+# All inner classes import the same list.
+our @CARP_NOT = qw[
+  DBIx::DataModel::Compatibility::V0
+  DBIx::DataModel::Compatibility::V1
+  DBIx::DataModel::ConnectedSource
+  DBIx::DataModel::Meta
+  DBIx::DataModel::Meta::Association
+  DBIx::DataModel::Meta::Path
+  DBIx::DataModel::Meta::Schema
+  DBIx::DataModel::Meta::Source
+  DBIx::DataModel::Meta::Source::Join
+  DBIx::DataModel::Meta::Source::Table
+  DBIx::DataModel::Meta::Type
+  DBIx::DataModel::Schema
+  DBIx::DataModel::Schema::Generator
+  DBIx::DataModel::Source
+  DBIx::DataModel::Source::Table
+  DBIx::DataModel::Source::Join
+  DBIx::DataModel::Statement
+  DBIx::DataModel::Statement::JDBC
+  SQL::Abstract
+  SQL::Abstract::More
+];
 
 
 sub define_schema {
@@ -39,14 +50,25 @@ sub define_schema {
 }
 
 sub Schema { # syntactic sugar for ->define_schema()
-  my $class             = shift;
-  my $schema_class_name = shift;
-  my %params  = scalar(@_) == 1 && does($_[0], 'HASH') ? %{$_[0]} : @_;
+  my ($class, $schema_class_name, %params) = @_;
   my $meta_schema = $class->define_schema(class => $schema_class_name, %params);
   return $meta_schema->class;
 }
 
 
+sub import {
+  my ($class, %args) = @_;
+  if (exists $args{-compatibility}) {
+    $COMPATIBILITY = $args{-compatibility} # explicit number
+                  || $VERSION;             # undef : means no compatibility
+  }
+
+  require DBIx::DataModel::Compatibility::V1 if $COMPATIBILITY < 1.99;
+  require DBIx::DataModel::Compatibility::V0 if $COMPATIBILITY < 1.00;
+}
+
+
+
 1; # End of DBIx::DataModel
 
 __END__
@@ -60,13 +82,12 @@ DBIx::DataModel - UML-based Object-Relational Mapping (ORM) framework
 Version 2 of C<DBIx::DataModel> is a major refactoring from versions
 1.*, with a number of incompatible changes in the API (classes
 renamed, arguments renamed or reorganized, etc. -- see
-L<DBIx::DataModel::Doc::Delta_v2>). 
-
-Initial subversions of the 2.* family included a layer of
-compatibility with version 1.*, so that old applications would
-continue to work (see L<DBIx::DataModel::Compatibility::V1>). Since
-version 2.20, this compatibility layer is no longer loaded
-automatically; however, it can still be added on demand by writing
+L<DBIx::DataModel::Doc::Delta_v2>). For the moment, 
+a compatibility layer is automatically loaded, so that applications
+written for prior versions will continue to work
+(see L<DBIx::DataModel::Compatibility::V1>). Some time in the
+future, the compatibility layer will be deprecated, and will need to be
+explicitly required through
 
   use DBIx::DataModel -compatibility => 1.0;
 
@@ -76,9 +97,9 @@ automatically; however, it can still be added on demand by writing
 
 =head3 Schema 
 
-Load C<DBIx::DataModel>.
+Load C<DBIx::DataModel>, without any backwards compatibility.
 
-  use DBIx::DataModel;
+  use DBIx::DataModel -compatibility => undef;
 
 Declare the schema, either in shorthand notation :
 
@@ -143,22 +164,14 @@ examples of column types :
      from_DB  => sub {$_[0] = [split /;/, $_[0] || ""]     },
      to_DB    => sub {$_[0] = join ";", @$_[0] if ref $_[0]},
     });
-  
-  # adding SQL type information for the DBD handler
-  My::Schema->metadm->define_type(
-    name     => 'XML',
-    handlers => {
-     to_DB    => sub {$_[0] = [{dbd_attrs => {ora_type => ORA_XMLTYPE}}, $_[0]]
-                        if $_[0]},
-    });
 
 =head3 Tables
 
 Declare the tables, either in shorthand notation :
 
-  My::Schema->Table(qw/Employee   T_Employee   emp_id/)
-            ->Table(qw/Department T_Department dpt_id/)
-            ->Table(qw/Activity   T_Activity   act_id/);
+  MySchema->Table(qw/Employee   T_Employee   emp_id/)
+          ->Table(qw/Department T_Department dpt_id/)
+          ->Table(qw/Activity   T_Activity   act_id/);
 
 or in verbose form :
 
@@ -277,7 +290,7 @@ just add a new method into the table class :
 
 Declare how to automatically expand objects into data trees
 
-  My::Schema::Activity->metadm->define_auto_expand(qw/employee department/);
+  My::Schema::Activity->metadm->set_auto_expand(qw/employee department/);
 
 =head3 Automatic schema generation
 
@@ -436,62 +449,6 @@ into an array (they must be used immediately) :
     do_something_immediately_with($row);
   }
 
-=head3 Insert
-
-  my $table = $schema->table($table_name);
-
-  #  If you provide the primary key (called 'my_code' in this example):
-  $table->insert({my_code => $pk_val, field1 => $val1, field2 => $val2, ...});
-
-  #  If your database provides the primary key:
-  my $id = $table->insert({field1 => $val1, field2 => $val2, ...});
-  #  This assumes your DBD driver implements last_insert_id.
-  #  If not, you can provide one as an option to the schema.
-
-  #  Insert multiple records using a list of arrayrefs.
-  #  First arrayref defines column names
-  $table->insert(
-                  [qw/  field1  field2  /],
-                  [qw/  val11   val12   /],
-                  [qw/  val22   val22   /],
-                );
-
-  #  Or just insert a list of hashes
-  $table->insert(
-      {field1 => val11, field2 => val12},
-      {field2 => val21, field2 => val22},
-  );
-
-  # insertion through the association Employee - Activity
-  $an_employee->insert_into_activities({d_begin => $today,
-                                        dpt_id  => $dpt});
-
-=head3 Update
-
-  # update on a set of fields, primary key included
-  my $table = $schema->table($table_name);
-  $table->update({pk_field => $pk, field1 => $val1, field2 => $val2, ...});
-
-  # update on a set of fields, primary key passed separately
-  $table->update(@primary_key, {field1 => $val1, field2 => $val2, ...});
-
-  # bulk update
-  $table->update(-set   => {field1 => $val1, field2 => $val2, ...},
-                 -where => \%condition);
-
-  # invoking instances instead of table classes
-  $obj->update({field1 => $val1, ...}); # updates specified fields
-  $obj->update;                         # updates all fields stored in memory
-
-
-=head3 Delete
-
-  # invoking a table class
-  my $table = $schema->table($table_name);
-  $table->delete(@primary_key);
-
-  # invoking an instance
-  $obj->delete;
 
 
 =head1 DESCRIPTION
@@ -561,9 +518,8 @@ of its strong points :
 
 =item *
 
-Centralized, UML-style declaration of tables and relationships 
-(instead of many files with declarations such as 'has_many', 'belongs_to', 
-etc.)
+UML-style declaration of relationships (instead of 'has_many', 
+'belongs_to', etc.)
 
 =item *
 
@@ -574,7 +530,7 @@ efficiency through fine control of collaboration with the DBI layer
 
 uses L<SQL::Abstract::More> for an improved API
 over L<SQL::Abstract> (named parameters, additional clauses,
-simplified 'order_by', support for values with associated datatypes, etc.)
+simplified 'order_by', etc.)
 
 =item *
 
@@ -612,7 +568,7 @@ named placeholders
 
 nested, cross-database transactions
 
-=item *
+item *
 
 choice between 'single-schema' mode (default, more economical) 
 and 'multi-schema' mode (optional, more flexible, but a little
@@ -775,21 +731,12 @@ Laurent Dami, E<lt>laurent.dami AT etat  ge  chE<gt>
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to
-
-  Ross Attril
-  Cedric Bouvier
-  Terrence Brannon
-  Alex Solovey
-  Sergiy Zuban
-
-who contributed with ideas, bug fixes and/or
-improvements.
-
+Thanks to Cedric Bouvier for some bug fixes and improvements, and to
+Terrence Brannon for many fixes in the documentation.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2013 by Laurent Dami.
+Copyright 2006-2011 by Laurent Dami.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
