@@ -2,6 +2,7 @@ package DBIx::DataModel::Meta::Association;
 use strict;
 use warnings;
 use parent "DBIx::DataModel::Meta";
+use DBIx::DataModel;
 use DBIx::DataModel::Meta::Utils;
 
 use Carp;
@@ -99,7 +100,7 @@ sub new {
   $self->$install_method(qw/B A/) if $self->{A}{role};
 
   # EXPERIMENTAL : no longer need association ends; all info is stored in Paths
-  # delete@{$self}{qw/A B/};
+  delete@{$self}{qw/A B/};
 
   # avoid circular reference
   weaken $self->{schema};
@@ -108,10 +109,9 @@ sub new {
 }
 
 
-# accessor methods for all members of %$self
+# accessor methods
 DBIx::DataModel::Meta::Utils->define_readonly_accessors(
-#  __PACKAGE__, qw/schema name kind path_AB path_BA/
-  __PACKAGE__, keys(%$association_spec), "path_AB", "path_BA",
+  __PACKAGE__, qw/schema name kind path_AB path_BA/,
 );
 
 
