@@ -3,16 +3,19 @@ use strict;
 use warnings;
 use parent 'DBIx::DataModel::Meta';
 use DBIx::DataModel;
-use DBIx::DataModel::Meta::Utils qw/define_class define_readonly_accessors/;
+use DBIx::DataModel::Meta::Utils;
 use DBIx::DataModel::Source::Join;
 use DBIx::DataModel::Meta::Source::Join;
 
-use Params::Validate     qw/validate_with SCALAR ARRAYREF CODEREF UNDEF BOOLEAN
-                                          OBJECT HASHREF/;
-use List::MoreUtils      qw/any firstval lastval uniq/;
+use Params::Validate     qw/validate SCALAR ARRAYREF CODEREF UNDEF BOOLEAN
+                                     OBJECT HASHREF/;
+use List::MoreUtils      qw/any lastval/;
+use Scalar::Util         qw/reftype/;
 use Module::Load         qw/load/;
-use Carp::Clan           qw[^(DBIx::DataModel::|SQL::Abstract)];
-use namespace::clean;
+use Carp;
+use namespace::autoclean;
+
+{no strict 'refs'; *CARP_NOT = \@DBIx::DataModel::CARP_NOT;}
 
 #----------------------------------------------------------------------
 # Params::Validate specification for new()
@@ -25,7 +28,6 @@ my $spec = {
                                    default => 'DBIx::DataModel::Schema'},
 
   sql_no_inner_after_left_join => {type => BOOLEAN, optional => 1},
-  join_with_USING              => {type => BOOLEAN, optional => 1},
 
   # fields below are in common with tables (schema is a kind of "pseudo-root")
   auto_insert_columns          => {type => HASHREF, default => {}},
@@ -61,6 +63,10 @@ my $statement_class = 'DBIx::DataModel::Statement';
 $spec->{statement_class}        = {type    => SCALAR, 
                                    isa     => $statement_class,
                                    default => $statement_class};
+my $connected_source_class = 'DBIx::DataModel::ConnectedSource';
+$spec->{connected_source_class} = {type    => SCALAR, 
+                                   isa     => $connected_source_class,
+                                   default => $connected_source_class};
 
 
 #----------------------------------------------------------------------
@@ -71,11 +77,7 @@ sub new {
   my $class = shift;
 
   # check parameters
-  my $self = validate_with(
-    params      => \@_,
-    spec        => $spec,
-    allow_extra => 0,
-   );
+  my $self = validate(@_, $spec);
 
   # canonical representations (arrayref) for some attributes
   for my $attr (qw/isa table_parent parent join_parent/) {
@@ -93,7 +95,7 @@ sub new {
   bless $self, $class;
 
   # create the Perl class
-  define_class(
+  DBIx::DataModel::Meta::Utils->define_class(
     name    => $self->{class},
     isa     => $isa,
     metadm  => $self,
@@ -103,7 +105,9 @@ sub new {
 }
 
 # accessors for args passed to new()
-define_readonly_accessors(__PACKAGE__, grep {$_ ne 'isa'} keys %$spec);
+DBIx::DataModel::Meta::Utils->define_readonly_accessors(
+  __PACKAGE__, grep {$_ ne 'isa'} keys %$spec
+ );
 
 # accessors for internal lists of other meta-objects
 foreach my $kind (qw/table association type join/) {
@@ -111,7 +115,7 @@ foreach my $kind (qw/table association type join/) {
   # retrieve list of meta-objects
   *{$kind."s"} = sub {
     my $self = shift;
-    return values %{$self->{$kind}};
+    return values %{$_[0]->{$kind}};
   };
 
   # retrieve single named object
@@ -124,11 +128,6 @@ foreach my $kind (qw/table association type join/) {
 }
 
 
-sub db_table {
-  my ($self, $db_name) = @_;
-  return firstval {uc($_->db_from) eq uc($db_name)} $self->tables;
-}
-
 
 #----------------------------------------------------------------------
 # PUBLIC FRONT-END METHODS FOR DECLARING SCHEMA MEMBERS
@@ -144,9 +143,6 @@ sub Table {
 
   # parse positional parameters (old syntax)
   my ($class_name, $db_name, @primary_key) = @_;
-  $db_name && @primary_key
-    or croak "not enough args to \$schema->Table(); "
-           . "did you mean \$schema->table() ?";
   $args{class}       ||= $class_name;
   $args{db_name}     ||= $db_name;
   $args{primary_key} ||= \@primary_key;
@@ -267,7 +263,6 @@ sub define_join {
     my $join_spec = {
       operator  => $join->{kind},
       condition => $join->{condition},
-      using     => $join->{using},
     };
     push @sqla_join_args, $join_spec, $join->{db_table};
   }
@@ -276,7 +271,7 @@ sub define_join {
   my %args = (
     schema         => $self,
     class          => $class_name,
-    parents        => [uniq map {$_->{table}} @$joins],
+    parents        => [map {$_->{table}} @$joins],
     sqla_join_args => \@sqla_join_args,
     aliased_tables => $aliased_tables,
   );
@@ -335,9 +330,7 @@ sub _parse_join_path {
   # build first member of the @join result
   my %first_join = (kind => '', name => $initial_table);
   $initial_table =~ s/\|(.+)$//  and $first_join{alias} = $1;
-  my $table = $self->table($initial_table)
-    or croak "...->join('$initial_table', ...) : this schema has "
-           . "no table named '$initial_table'";
+  my $table = $self->table($initial_table);
   $first_join{table}       = $table;
   $first_join{primary_key} = [$table->primary_key];
   $first_join{db_table}    = $table->db_from;
@@ -353,9 +346,8 @@ sub _parse_join_path {
   my $seen_left_join;
 
   foreach my $join_name (@join_names) {
-
-    # if it is a connector like '=>' or '<=>' or '<=' (see SQLAM syntax) ...
-    if ($join_name =~ /^[<>]?=[<>=]?$/) {
+    # if it is a INNER (<=>) or LEFT (=>) connector ..
+    if ($join_name =~ /^<?=>$/) {
       !$join_kind or croak "'$join_kind' can't be followed by '$join_name'";
       $join_kind = $join_name;
       # TODO: accept more general join syntax as recognized by SQLA::More::join
@@ -388,23 +380,9 @@ sub _parse_join_path {
       # build new join hashref and insert it into appropriate structures
       my $left_table  = $source_join->{alias} || $source_join->{db_table};
       my $right_table = $alias || $path->{to}->db_from;
-      my %condition;   # for joining with a ON clause
-      my $using = [];  # for joining with a USING clause
+      my %condition;
       while (my ($left_col, $right_col) = each %{$path->{on}}) {
-        if ($left_col eq $right_col) {
-          # both cols of equal name ==> can participate in a USING clause
-          push @$using, $left_col if $using;
-        }
-        else {
-          # USING clause no longer possible as soon as there are unequal names
-          undef $using;
-        }
-
-        # for the ON clause, prefix column names by their table names
-        # FIXME: honor SQL::Abstract's "name_sep" setting
-        $left_col  = "$left_table.$left_col";
-        $right_col = "$right_table.$right_col";
-        $condition{$left_col} = { -ident => $right_col };
+        $condition{"$left_table.$left_col"} = \"= $right_table.$right_col";
       }
       my $db_table = $path->{to}->db_from;
       $db_table .= "|$alias" if $alias;
@@ -413,9 +391,7 @@ sub _parse_join_path {
                        alias     => $alias,
                        table     => $path->{to},
                        db_table  => $db_table,
-                       condition => \%condition,
-                       using     => $using,
-                     };
+                       condition => \%condition,   };
       push @joins, $new_join;
       $source{$alias || $path_name} = $new_join;
 
