@@ -3,14 +3,15 @@ use strict;
 use warnings;
 use parent "DBIx::DataModel::Meta";
 use DBIx::DataModel;
-use DBIx::DataModel::Meta::Utils qw/define_class define_readonly_accessors/;
+use DBIx::DataModel::Meta::Utils;
 
-use Params::Validate qw/validate_with SCALAR ARRAYREF HASHREF OBJECT/;
+use Params::Validate qw/validate SCALAR ARRAYREF HASHREF OBJECT/;
 use Scalar::Util     qw/weaken/;
 use List::MoreUtils  qw/any/;
-use Carp::Clan       qw[^(DBIx::DataModel::|SQL::Abstract)];
+use Carp;
+use namespace::autoclean;
 
-use namespace::clean;
+{no strict 'refs'; *CARP_NOT = \@DBIx::DataModel::CARP_NOT;}
 
 #----------------------------------------------------------------------
 # COMPILE-TIME METHODS
@@ -27,7 +28,9 @@ my %common_arg_spec = (
   # other slot filled later : 'name'
 );
 
-define_readonly_accessors(__PACKAGE__, keys %common_arg_spec, 'name');
+DBIx::DataModel::Meta::Utils->define_readonly_accessors(
+  __PACKAGE__, keys %common_arg_spec, 'name'
+);
 
 
 sub _new_meta_source { # called by new() in Meta::Table and Meta::Join
@@ -39,11 +42,7 @@ sub _new_meta_source { # called by new() in Meta::Table and Meta::Join
   my %spec = (%common_arg_spec, %$more_arg_spec);
 
   # validate the parameters
-  my $self = validate_with(
-    params      => \@_,
-    spec        => \%spec,
-    allow_extra => 0,
-   );
+  my $self = validate(@_, \%spec);
 
   # force into arrayref if accepts ARRAYREF but given as scalar
   for my $attr (grep {($spec{$_}{type} || 0) & ARRAYREF} keys %spec) {
@@ -73,7 +72,7 @@ sub _new_meta_source { # called by new() in Meta::Table and Meta::Join
   }
 
   # create the Perl class
-  define_class(
+  DBIx::DataModel::Meta::Utils->define_class(
     name   => $self->{class},
     isa    => \@isa,
     metadm => $self,
@@ -117,18 +116,11 @@ sub _consolidate_hash {
   my ($self, $field, $optional_hash_key) = @_;
   my %hash;
 
-  my @meta_sources = ($self, $self->ancestors, $self->{schema});
-
-  foreach my $meta_source (reverse @meta_sources) {
+  foreach my $meta_source ($self, $self->ancestors, $self->{schema}) {
     while (my ($name, $val) = each %{$meta_source->{$field} || {}}) {
-      $val ? $hash{$name} = $val : delete $hash{$name};
+      $hash{$name} ||= $val;
     }
   }
-  # foreach my $meta_source ($self, $self->ancestors, $self->{schema}) {
-  #   while (my ($name, $val) = each %{$meta_source->{$field} || {}}) {
-  #     $hash{$name} ||= $val;
-  #   }
-  # }
   return $optional_hash_key ? $hash{$optional_hash_key} : %hash;
 }
 
