@@ -6,95 +6,56 @@ use strict;
 use warnings;
 
 use Carp;
-use Module::Load               qw/load/;
-use Params::Validate           qw/validate_with SCALAR ARRAYREF CODEREF
-                                                BOOLEAN OBJECT HASHREF/;
-use List::MoreUtils            qw/any/;
-use mro                        qw/c3/;
+use Module::Load         qw/load/;
+use Params::Validate     qw/validate SCALAR ARRAYREF CODEREF UNDEF BOOLEAN
+                                     OBJECT HASHREF/;
+use mro 'c3';
+use namespace::autoclean;
+
 use DBIx::DataModel;
-use SQL::Abstract::More 1.33;
-use Carp::Clan                 qw[^(DBIx::DataModel::|SQL::Abstract)];
-use Exporter                   qw/import/;
-
-our @EXPORT = qw/define_class define_method define_readonly_accessors
-                 does/;
-
-
-BEGIN {no strict 'refs'; *does = \&SQL::Abstract::More::does;}
-
-
-sub _check_call_as_class_method {
-  my $first_arg = $_[0];
-
-  if ($first_arg && !ref $first_arg && $first_arg->isa(__PACKAGE__) ) {
-    my $func = (caller(1))[3];
-    carp "calling $func() as class method is obsolete; import and call as a function";
-    shift @_;
-  }
-}
-
-
+{no strict 'refs'; *CARP_NOT = \@DBIx::DataModel::CARP_NOT;}
 
 sub define_class {
-  &_check_call_as_class_method;
+  my $self = shift;
 
   # check parameters
-  my %params = validate_with(
-    params => \@_,
-    spec   => {
+  my %params = validate(@_, {
       name    => {type => SCALAR  },
       isa     => {type => ARRAYREF},
       metadm  => {isa  => 'DBIx::DataModel::Meta'},
-    },
-    allow_extra => 0,
+    }
   );
 
   # deactivate strict refs because we'll be playing with symbol tables
   no strict 'refs';
 
-  # make sure that all parents are defined
-  foreach my $parent (@{$params{isa}}) {
-
-    # heuristics to decide if a class is loaded (can't rely on %INC)
-    my $is_class_defined = any {! /::$/} keys %{$parent.'::'};
-      # NOTE : we need to exclude symbols ending with '::' because
-      # "require Foo::Bar::Buz" will define ${Foo::Bar::}{'Buz::'} at
-      # compilation time, even if this statement is never executed.
-
-    # try to load parent if needed
-    load $parent unless $is_class_defined;
-  };
-
   # inject parents into @ISA
+  %{$_.'::'} or load $_ foreach @{$params{isa}};
   my $class_isa = $params{name}."::ISA";
-  not @{$class_isa} or croak "won't overwrite \@$class_isa";
+  not defined  @{$class_isa} or croak "won't overwrite \@$class_isa";
   @{$class_isa} = @{$params{isa}};
 
   # use mro 'c3' in that package
   mro::set_mro($params{name}, 'c3');
 
   # install an accessor to the metaclass object within the package
-  define_method(class          => $params{name},
-                name           => 'metadm', 
-                body           => sub {return $params{metadm}},
-                check_override => 0,                          );
+  $self->define_method(class          => $params{name},
+                       name           => 'metadm', 
+                       body           => sub {return $params{metadm}},
+                       check_override => 0,                          );
 }
 
 
 sub define_method {
-  &_check_call_as_class_method;
+  my $self = shift;
 
-  
   # check parameters
-  my %params = validate_with(
-    params => \@_,
-    spec   => {
+  my %params = validate(@_, {
       class          => {type => SCALAR               },
       name           => {type => SCALAR               },
       body           => {type => CODEREF              },
       check_override => {type => BOOLEAN, default => 1},
-    },
-    allow_extra => 0,
+    }
   );
 
   # fully qualified name
@@ -117,12 +78,10 @@ sub define_method {
 
 
 sub define_readonly_accessors {
-  &_check_call_as_class_method;
-
-  my ($target_class, @accessors) = @_;
+  my ($self, $target_class, @accessors) = @_;
 
   foreach my $accessor (@accessors) {
-    define_method(
+    $self->define_method(
       class => $target_class,
       name  => $accessor, 
       body  => sub { my $self = shift;
